@@ -1,14 +1,8 @@
 ### R code from vignette source 'HTSCluster.Rnw'
 
 ###################################################
-### code chunk number 1: options
+### code chunk number 1: load (eval = FALSE)
 ###################################################
-options(digits=3, width=100)
-
-
-###################################################
-### code chunk number 2: sessi
-###################################################
-sessionInfo()
-
+## library(HTSCluster)
+## HTSClusterUsersGuide()
 
